@@ -85,7 +85,7 @@ class SequencingStatistics:
     @property
     def fastq_y(self):
         """
-        Return te number of ocnnected positions to calulcate where to write the fastq statistics
+        Return te number of connected positions to calulcate where to write the fastq statistics
         Returns
         -------
 
@@ -674,6 +674,16 @@ def add_arguments_to_parser(parser, stdscr):
         help="Set the primer scheme to use for artic tasks. Valid options can be seen using --list.",
         dest="primer_scheme"
     )
+    parser.add_argument(
+        "-cc",
+        "--concat_conditions",
+        default=False,
+        required=False,
+        help="On ReadFish runs, concatenate the reads barcode name and the condition ReadFish has for it's channel. "
+             "Default False. ",
+        dest="concat_condish",
+        action="store_true",
+    )
     return parser
 
 
@@ -753,7 +763,7 @@ def check_server_compatibility(minotour_api, log):
             log.error(client)
         raise Exception(
             "Server does not support this client. "
-            "Please change the client to a previous version or upgrade server."
+            f"Please change your client to any of {clients} or upgrade your minoTour server."
         )
     else:
         return "minFQ version: {} is compatible with minoTour server specified.\n".format(
@@ -882,7 +892,7 @@ def check_job_from_client(args, log, minotour_api, parser):
             "Can't find the job type chosen. Please double check that it is the same ID shown by --list."
         )
 
-    if args.job == "minimap2" or args.job == 4:
+    if args.job == "minimap2" or args.job in {4, 5}:
         if args.reference == None:
             log.error("You need to specify a reference for a Minimap2 task.")
             sys.exit(0)
